/* This file was generated by syncqt. */
#ifndef QT_QT3DRENDER_VERSION_H
#define QT_QT3DRENDER_VERSION_H

#define QT3DRENDER_VERSION_STR "6.11.1"

#define QT3DRENDER_VERSION 0x0601101

#endif // QT_QT3DRENDER_VERSION_H
