// Copyright (C) 2015 Klaralvdalens Datakonsult AB (KDAB).
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QT3DINPUT_GLOBAL_P_H
#define QT3DINPUT_GLOBAL_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of other Qt classes.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qt3dinput_global.h"
#include <private/qglobal_p.h>

#define Q_3DINPUTSHARED_PRIVATE_EXPORT Q_3DINPUTSHARED_EXPORT

#endif // QT3DINPUT_GLOBAL_P_H

